==> hinemos_manager-4.0.3_rhel6_32.tar.gz: com/clustercontrol/ws/monitor/ObjectFactory.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.clustercontrol.ws.monitor package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.clustercontrol.ws.monitor
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link PerfCheckInfo }
     * 
     */
    public PerfCheckInfo createPerfCheckInfo() {
        return new PerfCheckInfo();
    }

    /**
     * Create an instance of {@link CommandExecuteDTO }
     * 
     */
    public CommandExecuteDTO createCommandExecuteDTO() {
        return new CommandExecuteDTO();
    }

    /**
     * Create an instance of {@link MonitorJudgementInfo }
     * 
     */
    public MonitorJudgementInfo createMonitorJudgementInfo() {
        return new MonitorJudgementInfo();
    }

    /**
     * Create an instance of {@link ProcessCheckInfo }
     * 
     */
    public ProcessCheckInfo createProcessCheckInfo() {
        return new ProcessCheckInfo();
    }

    /**
     * Create an instance of {@link HttpCheckInfo }
     * 
     */
    public HttpCheckInfo createHttpCheckInfo() {
        return new HttpCheckInfo();
    }

    /**
     * Create an instance of {@link CommandResultDTO.Results }
     * 
     */
    public CommandResultDTO.Results createCommandResultDTOResults() {
        return new CommandResultDTO.Results();
    }

    /**
     * Create an instance of {@link SnmpCheckInfo }
     * 
     */
    public SnmpCheckInfo createSnmpCheckInfo() {
        return new SnmpCheckInfo();
    }

    /**
     * Create an instance of {@link CommandResultDTO.Results.Entry }
     * 
     */
    public CommandResultDTO.Results.Entry createCommandResultDTOResultsEntry() {
        return new CommandResultDTO.Results.Entry();
    }

    /**
     * Create an instance of {@link CustomCheckInfo }
     * 
     */
    public CustomCheckInfo createCustomCheckInfo() {
        return new CustomCheckInfo();
    }

    /**
     * Create an instance of {@link CommandResultDTO }
     * 
     */
    public CommandResultDTO createCommandResultDTO() {
        return new CommandResultDTO();
    }

    /**
     * Create an instance of {@link CommandResultDTO.InvalidLines.Entry }
     * 
     */
    public CommandResultDTO.InvalidLines.Entry createCommandResultDTOInvalidLinesEntry() {
        return new CommandResultDTO.InvalidLines.Entry();
    }

    /**
     * Create an instance of {@link MonitorInfo }
     * 
     */
    public MonitorInfo createMonitorInfo() {
        return new MonitorInfo();
    }

    /**
     * Create an instance of {@link MonitorTruthValueInfo }
     * 
     */
    public MonitorTruthValueInfo createMonitorTruthValueInfo() {
        return new MonitorTruthValueInfo();
    }

    /**
     * Create an instance of {@link TrapCheckInfo }
     * 
     */
    public TrapCheckInfo createTrapCheckInfo() {
        return new TrapCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorNumericValueInfo }
     * 
     */
    public MonitorNumericValueInfo createMonitorNumericValueInfo() {
        return new MonitorNumericValueInfo();
    }

    /**
     * Create an instance of {@link CommandVariableDTO }
     * 
     */
    public CommandVariableDTO createCommandVariableDTO() {
        return new CommandVariableDTO();
    }

    /**
     * Create an instance of {@link MonitorCheckInfo }
     * 
     */
    public MonitorCheckInfo createMonitorCheckInfo() {
        return new MonitorCheckInfo();
    }

    /**
     * Create an instance of {@link CommandResultDTO.InvalidLines }
     * 
     */
    public CommandResultDTO.InvalidLines createCommandResultDTOInvalidLines() {
        return new CommandResultDTO.InvalidLines();
    }

    /**
     * Create an instance of {@link PortCheckInfo }
     * 
     */
    public PortCheckInfo createPortCheckInfo() {
        return new PortCheckInfo();
    }

    /**
     * Create an instance of {@link LogfileCheckInfo }
     * 
     */
    public LogfileCheckInfo createLogfileCheckInfo() {
        return new LogfileCheckInfo();
    }

    /**
     * Create an instance of {@link CommandVariableDTO.Variables }
     * 
     */
    public CommandVariableDTO.Variables createCommandVariableDTOVariables() {
        return new CommandVariableDTO.Variables();
    }

    /**
     * Create an instance of {@link CommandVariableDTO.Variables.Entry }
     * 
     */
    public CommandVariableDTO.Variables.Entry createCommandVariableDTOVariablesEntry() {
        return new CommandVariableDTO.Variables.Entry();
    }

    /**
     * Create an instance of {@link WinServiceCheckInfo }
     * 
     */
    public WinServiceCheckInfo createWinServiceCheckInfo() {
        return new WinServiceCheckInfo();
    }

    /**
     * Create an instance of {@link PingCheckInfo }
     * 
     */
    public PingCheckInfo createPingCheckInfo() {
        return new PingCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorStringValueInfo }
     * 
     */
    public MonitorStringValueInfo createMonitorStringValueInfo() {
        return new MonitorStringValueInfo();
    }

    /**
     * Create an instance of {@link MonitorTrapValueInfo }
     * 
     */
    public MonitorTrapValueInfo createMonitorTrapValueInfo() {
        return new MonitorTrapValueInfo();
    }

    /**
     * Create an instance of {@link SqlCheckInfo }
     * 
     */
    public SqlCheckInfo createSqlCheckInfo() {
        return new SqlCheckInfo();
    }

}

==> hinemos_manager-4.1.3_rhel6_32.tar.gz: com/clustercontrol/ws/monitor/ObjectFactory.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.clustercontrol.ws.monitor package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.clustercontrol.ws.monitor
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CommandResultDTO }
     * 
     */
    public CommandResultDTO createCommandResultDTO() {
        return new CommandResultDTO();
    }

    /**
     * Create an instance of {@link CommandResultDTO.Results }
     * 
     */
    public CommandResultDTO.Results createCommandResultDTOResults() {
        return new CommandResultDTO.Results();
    }

    /**
     * Create an instance of {@link CommandResultDTO.InvalidLines }
     * 
     */
    public CommandResultDTO.InvalidLines createCommandResultDTOInvalidLines() {
        return new CommandResultDTO.InvalidLines();
    }

    /**
     * Create an instance of {@link CommandVariableDTO }
     * 
     */
    public CommandVariableDTO createCommandVariableDTO() {
        return new CommandVariableDTO();
    }

    /**
     * Create an instance of {@link CommandVariableDTO.Variables }
     * 
     */
    public CommandVariableDTO.Variables createCommandVariableDTOVariables() {
        return new CommandVariableDTO.Variables();
    }

    /**
     * Create an instance of {@link CustomCheckInfo }
     * 
     */
    public CustomCheckInfo createCustomCheckInfo() {
        return new CustomCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorTrapValueInfo }
     * 
     */
    public MonitorTrapValueInfo createMonitorTrapValueInfo() {
        return new MonitorTrapValueInfo();
    }

    /**
     * Create an instance of {@link TrapCheckInfo }
     * 
     */
    public TrapCheckInfo createTrapCheckInfo() {
        return new TrapCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorTruthValueInfo }
     * 
     */
    public MonitorTruthValueInfo createMonitorTruthValueInfo() {
        return new MonitorTruthValueInfo();
    }

    /**
     * Create an instance of {@link MonitorInfo }
     * 
     */
    public MonitorInfo createMonitorInfo() {
        return new MonitorInfo();
    }

    /**
     * Create an instance of {@link MonitorStringValueInfo }
     * 
     */
    public MonitorStringValueInfo createMonitorStringValueInfo() {
        return new MonitorStringValueInfo();
    }

    /**
     * Create an instance of {@link PingCheckInfo }
     * 
     */
    public PingCheckInfo createPingCheckInfo() {
        return new PingCheckInfo();
    }

    /**
     * Create an instance of {@link ProcessCheckInfo }
     * 
     */
    public ProcessCheckInfo createProcessCheckInfo() {
        return new ProcessCheckInfo();
    }

    /**
     * Create an instance of {@link PerfCheckInfo }
     * 
     */
    public PerfCheckInfo createPerfCheckInfo() {
        return new PerfCheckInfo();
    }

    /**
     * Create an instance of {@link SqlCheckInfo }
     * 
     */
    public SqlCheckInfo createSqlCheckInfo() {
        return new SqlCheckInfo();
    }

    /**
     * Create an instance of {@link HttpCheckInfo }
     * 
     */
    public HttpCheckInfo createHttpCheckInfo() {
        return new HttpCheckInfo();
    }

    /**
     * Create an instance of {@link WinServiceCheckInfo }
     * 
     */
    public WinServiceCheckInfo createWinServiceCheckInfo() {
        return new WinServiceCheckInfo();
    }

    /**
     * Create an instance of {@link PluginCheckInfo }
     * 
     */
    public PluginCheckInfo createPluginCheckInfo() {
        return new PluginCheckInfo();
    }

    /**
     * Create an instance of {@link LogfileCheckInfo }
     * 
     */
    public LogfileCheckInfo createLogfileCheckInfo() {
        return new LogfileCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorPluginNumericInfo }
     * 
     */
    public MonitorPluginNumericInfo createMonitorPluginNumericInfo() {
        return new MonitorPluginNumericInfo();
    }

    /**
     * Create an instance of {@link MonitorNumericValueInfo }
     * 
     */
    public MonitorNumericValueInfo createMonitorNumericValueInfo() {
        return new MonitorNumericValueInfo();
    }

    /**
     * Create an instance of {@link SnmpCheckInfo }
     * 
     */
    public SnmpCheckInfo createSnmpCheckInfo() {
        return new SnmpCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorCheckInfo }
     * 
     */
    public MonitorCheckInfo createMonitorCheckInfo() {
        return new MonitorCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorPluginStringInfo }
     * 
     */
    public MonitorPluginStringInfo createMonitorPluginStringInfo() {
        return new MonitorPluginStringInfo();
    }

    /**
     * Create an instance of {@link CommandExecuteDTO }
     * 
     */
    public CommandExecuteDTO createCommandExecuteDTO() {
        return new CommandExecuteDTO();
    }

    /**
     * Create an instance of {@link WinEventCheckInfo }
     * 
     */
    public WinEventCheckInfo createWinEventCheckInfo() {
        return new WinEventCheckInfo();
    }

    /**
     * Create an instance of {@link MonitorJudgementInfo }
     * 
     */
    public MonitorJudgementInfo createMonitorJudgementInfo() {
        return new MonitorJudgementInfo();
    }

    /**
     * Create an instance of {@link PortCheckInfo }
     * 
     */
    public PortCheckInfo createPortCheckInfo() {
        return new PortCheckInfo();
    }

    /**
     * Create an instance of {@link CommandResultDTO.Results.Entry }
     * 
     */
    public CommandResultDTO.Results.Entry createCommandResultDTOResultsEntry() {
        return new CommandResultDTO.Results.Entry();
    }

    /**
     * Create an instance of {@link CommandResultDTO.InvalidLines.Entry }
     * 
     */
    public CommandResultDTO.InvalidLines.Entry createCommandResultDTOInvalidLinesEntry() {
        return new CommandResultDTO.InvalidLines.Entry();
    }

    /**
     * Create an instance of {@link CommandVariableDTO.Variables.Entry }
     * 
     */
    public CommandVariableDTO.Variables.Entry createCommandVariableDTOVariablesEntry() {
        return new CommandVariableDTO.Variables.Entry();
    }

}
